==> openiec61850-0.9.5.tgz: openiec61850/openiec61850-common/src/main/java/org/openiec61850/client/ClientACSI.java <==
/*
 * Copyright Fraunhofer ISE, energy & meteo Systems GmbH, and other contributors 2011
 *
 * This file is part of openIEC61850.
 * For more information visit http://www.openmuc.org 
 *
 * openIEC61850 is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * openIEC61850 is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with openIEC61850.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
package org.openiec61850.client;

import org.openiec61850.common.ServiceError;
import org.openiec61850.common.model.ModelNode;
import org.openiec61850.common.model.Server;

/**
 * @author Stefan Feuerhahn
 * @author Tobias Weidelt
 */
public interface ClientACSI {
	public enum ServerDirectoryType {
		LOGICAL_DEVICES, FILES
	}

	Server retrieveModel() throws ServiceError;

	ModelNode getDataValues(ModelNode modelNode) throws ServiceError;

	ModelNode setDataValues(ModelNode modelNode) throws ServiceError;

	// void createDataSet(DataSet dataSet, Server server) throws ServiceError;
	// void deleteDataSet(DataSet dataSet, Server server) throws ServiceError;
	// void updateDataSetDirectories(Server server) throws ServiceError;
	// void setReportReceiver(ReportReceiver reportReceiver);

	void close();

}

==> openiec61850-0.9.9.tgz: openiec61850/openiec61850-common/src/main/java/org/openiec61850/client/ClientACSI.java <==
/*
 * Copyright Fraunhofer ISE, energy & meteo Systems GmbH, and other contributors 2011
 *
 * This file is part of openIEC61850.
 * For more information visit http://www.openmuc.org 
 *
 * openIEC61850 is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * openIEC61850 is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with openIEC61850.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
package org.openiec61850.client;

import java.util.List;

import org.openiec61850.common.ServiceError;
import org.openiec61850.common.model.DataSet;
import org.openiec61850.common.model.LogicalDevice;
import org.openiec61850.common.model.ModelNode;
import org.openiec61850.common.model.Server;
import org.openiec61850.common.model.report.Report;
import org.openiec61850.common.model.report.ReportControlBlock;

/**
 * @author Stefan Feuerhahn
 * @author Tobias Weidelt
 */
public interface ClientACSI {
	public enum ServerDirectoryType {
		LOGICAL_DEVICES, FILES
	}

	Server retrieveModel() throws ServiceError;
	
	void retrieveDataSets(List<LogicalDevice> lds) throws ServiceError;

	ModelNode getDataValues(ModelNode modelNode) throws ServiceError;

	void setDataValues(ModelNode modelNode) throws ServiceError;

	void createDataSet(DataSet dataSet) throws ServiceError;
	int[] deleteDataSet(DataSet dataSet) throws ServiceError;
	List<String> setDataSetValues(DataSet dataSet) throws ServiceError;
	void getDataSetValues(DataSet dataSet) throws ServiceError;
	// void updateDataSetDirectories(Server server) throws ServiceError;
	// void setReportReceiver(ReportReceiver reportReceiver);
	
	void getRCBValues(ReportControlBlock rcb) throws ServiceError;
	void setRCBValues(ReportControlBlock rcb) throws ServiceError;
	
	Report getReport() throws ServiceError;
	Report getReport(int timeout) throws ServiceError;

	void close();

}
